Welcome to Django Downtime! — Django Downtime 1.0.2 documentation

# Welcome to Django Downtime!

## Overview

Small, simple, app to show a down page while you make upgrades.

## Purpose

This app simply runs middleware that checks to see if the site is down for maintenance. If it is, (with a period of downtime added to the apps models) either a redirect occurs or a template is loaded with a down time message. This app isn’t intended to be a full service solution as it still requires that the django site remain functional to work. In other cases it may be more beneficial to point your domain at a different server instead.

Contents:

- Installation
  - Settings
  - Templates
- Usage
  - Adding Downtime
  - Bringing The Site Back Up
- Contributors
- Changelog
  - 1.0.1
  - 1.0.0
  - 0.3.3
  - 0.3.2
  - 0.3.1
  - 0.3
  - 0.2
  - 0.1
- License